Suivez vos concurrents et voyez si la couverture est positive, négative ou neutre
Suivez plusieurs concurrents. Indiquez si la couverture est positive, négative ou neutre. Filtrez par qualité de la source et affichez les données au fil du temps
Paramètres d'entrée
| Paramètre | Description | Type | Valeur par défaut | Requis |
|---|---|---|---|---|
| organization.name | Plusieurs concurrents (séparés par des virgules). | string | Oui | |
| category.id | Filtre de catégorie. | string | Oui | |
| published_at.start | Date de début pour la période d'analyse. | string | Oui | |
| sort.by | Trier par score de sentiment. | string | Oui | |
| sort.order | Ordre décroissant. | string | Oui | |
| source.rank.opr.min | Qualité minimum de la source. | string | Oui | |
| is_duplicate | Exclure les doublons. | integer | 0 | Oui |
| api_key | Votre clé API | string | Oui | |
| per_page | Nombre maximum d'articles à récupérer | integer | 30 | Non |
Exemples de flux de travail
Analyse de la veille concurrentielle :
curl -X GET "https://api.apitube.io/v1/news/everything?organization.name=Tesla,Microsoft,Amazon&category.id=medtop:13000000&published_at.start=2023-01-01&sort.by=sentiment.overall.score&sort.order=desc&source.rank.opr.min=5&is_duplicate=0&api_key=YOUR_API_KEY"
Analyse de l'innovation intersectorielle :
curl -X GET "https://api.apitube.io/v1/news/everything?title=innovation&sentiment.overall.polarity=positive&published_at.start=2023-01-01&published_at.end=2023-01-31&category.id=medtop:04000000&api_key=YOUR_API_KEY"
Suivez si la couverture de l'organisation est positive, négative ou neutre lors d'événements financiers :
curl -X GET "https://api.apitube.io/v1/news/everything?organization.name=JPMorgan%20Chase&published_at.start=2023-04-01&published_at.end=2023-04-30&sort.by=published_at&sort.order=asc&category.id=medtop:04000000&api_key=YOUR_API_KEY"
Exemples connexes
- Analyser si la couverture est positive, négative ou neutre sur plusieurs dimensions
- Analyse de la réputation de la marque
- Trouvez avec quelles organisations une personne est mentionnée
- Obtenir des actualités sur un ton positif
- Triez par score d'engagement
Recette pour cURL
curl --location --globoff --request POST 'https://api.apitube.io/v1/news/everything?organization.name=Tesla%2CMicrosoft%2CAmazon&category.id=medtop%3A13000000&published_at.start=2023-01-01&sort.by=sentiment.overall.score&sort.order=desc&source.rank.opr.min=5&is_duplicate=0&api_key=YOUR_API_KEY&per_page=30' \
--header 'Content-Type: application/json'
Recette pour Python
import requests
url = "https://api.apitube.io/v1/news/everything"
querystring = {
"organization.name": "Tesla,Microsoft,Amazon",
"category.id": "medtop:13000000",
"published_at.start": "2023-01-01",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"source.rank.opr.min": 5,
"is_duplicate": 0,
"api_key": "YOUR_API_KEY",
"per_page": 30
}
response = requests.request("GET", url, params=querystring)
print(response.text)
Recette pour Javascript
import axios from "axios"
const options = {
method: 'GET',
url: 'https://api.apitube.io/v1/news/everything',
params: {
"organization.name": "Tesla,Microsoft,Amazon",
"category.id": "medtop:13000000",
"published_at.start": "2023-01-01",
"sort.by": "sentiment.overall.score",
"sort.order": "desc",
"source.rank.opr.min": 5,
"is_duplicate": 0,
"api_key": "YOUR_API_KEY",
"per_page": 30
}};
axios.request(options).then(function (response) {
console.log(response.data);
}).catch(function (error) {
console.error(error);
});
Recette pour PHP
require 'vendor/autoload.php';
use GuzzleHttp\Client;
$client = new Client();
$response = $client->request('GET', 'https://api.apitube.io/v1/news/everything', [
'query' => [
'organization.name' => 'Tesla,Microsoft,Amazon',
'category.id' => 'medtop:13000000',
'published_at.start' => '2023-01-01',
'sort.by' => 'sentiment.overall.score',
'sort.order' => 'desc',
'source.rank.opr.min' => 5,
'is_duplicate' => 0,
'api_key' => 'YOUR_API_KEY',
'per_page' => 30,
],
]);
echo $response->getBody();
Recette pour Java
OkHttpClient client = new OkHttpClient().newBuilder().build();
MediaType mediaType = MediaType.parse("application/json");
RequestBody body = RequestBody.create(mediaType, "");
Request request = new Request.Builder()
.url("https://api.apitube.io/v1/news/everything?organization.name=Tesla%2CMicrosoft%2CAmazon&category.id=medtop%3A13000000&published_at.start=2023-01-01&sort.by=sentiment.overall.score&sort.order=desc&source.rank.opr.min=5&is_duplicate=0&api_key=YOUR_API_KEY&per_page=30")
.method("POST", body)
.addHeader("Content-Type", "application/json")
.build();
Response response = client.newCall(request).execute();